==> haskell-cookie-0.4.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cookie
version: 0.4.4
id: cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
key: cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/cookie
synopsis: HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.
category: Web, Yesod
abi: 98943a44942d0f9eb24e49aaa7774a37
exposed: True
exposed-modules:
    Web.Cookie
import-dirs: /usr/lib/ghc-8.4.3/site-local/cookie-0.4.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/cookie-0.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cookie-0.4.4
hs-libraries: HScookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
depends:
    base-4.11.1.0 bytestring-0.10.8.2 time-1.8.0.2 text-1.2.3.0
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html: /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cookie-0.4.4-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cookie
version: 0.4.4
id: cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
key: cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/cookie
synopsis: HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.
category: Web, Yesod
abi: 2b2ad29e3b5c8ff8725c25149a60cd9e
exposed: True
exposed-modules:
    Web.Cookie
import-dirs: /usr/lib/ghc-8.6.1/site-local/cookie-0.4.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/cookie-0.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/cookie-0.4.4
hs-libraries: HScookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 deepseq-1.4.4.0
    text-1.2.3.1 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html: /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
